summaryrefslogtreecommitdiffstats
path: root/kword/KWTextParag.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kword/KWTextParag.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kword/KWTextParag.h')
-rw-r--r--kword/KWTextParag.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWTextParag.h b/kword/KWTextParag.h
index de484a48..b0a9d044 100644
--- a/kword/KWTextParag.h
+++ b/kword/KWTextParag.h
@@ -46,7 +46,7 @@ public:
KWTextDocument * kwTextDocument() const;
- virtual void setParagLayout( const KoParagLayout &layout, int flags = KoParagLayout::All, int marginIndex = -1 );
+ virtual void setParagLayout( const KoParagLayout &tqlayout, int flags = KoParagLayout::All, int marginIndex = -1 );
/** The type of page-breaking behaviour */
void setPageBreaking( int pb ); // warning this sets all the flags!
@@ -73,7 +73,7 @@ public:
/** Load (from KWord-1.3 XML) and apply \<FORMAT\> tags (used by KWTextParag::load and by KWPasteCommand) */
void loadFormatting( TQDomElement &attributes, int offset = 0, bool loadFootNote=true );
/** Load (from KWord-1.3 XML) and apply paragraph layout */
void loadLayout( TQDomElement & attributes );
/** Load (from KWord-1.3 XML), optionally using styles from document. */
@@ -73,7 +73,7 @@ public:
/** Load (from KWord-1.3 XML) and apply \<FORMAT\> tags (used by KWTextParag::load and by KWPasteCommand) */
void loadFormatting( TQDomElement &attributes, int offset = 0, bool loadFootNote=true );
- /** Load (from KWord-1.3 XML) and apply paragraph layout */
+ /** Load (from KWord-1.3 XML) and apply paragraph tqlayout */
void loadLayout( TQDomElement & attributes );
/** Load (from KWord-1.3 XML), optionally using styles from document. */